@@ -4,13 +4,10 @@ use strict;
 use warnings;
 use Carp;
 use FFI::Platypus::Buffer;
-use base 'Geo::GDAL::FFI::Object';
-
-our $VERSION = '0.13_004';
 
 sub DESTROY {
     my $self = shift;
-    Geo::GDAL::FFI::_deregister_parent_ref ($$self);
+    delete $Geo::GDAL::FFI::parent{$$self};
 }
 
 sub GetDataType {
@@ -36,26 +33,6 @@ sub GetSize {
         );
 }
 
-sub GetCategoryNames {
-    my $self = shift;
-    my $csl = Geo::GDAL::FFI::GDALGetRasterCategoryNames($$self);
-    my @names;
-    for my $i (0..Geo::GDAL::FFI::CSLCount($csl)-1) {
-        push @names, Geo::GDAL::FFI::CSLGetField($csl, $i);
-    }
-    return @names;
-}
-
-sub SetCategoryNames {
-    my ($self, @names) = @_;
-    my $csl = 0;
-    for my $n (@names) {
-        $csl = Geo::GDAL::FFI::CSLAddString($csl, $n);
-    }
-    Geo::GDAL::FFI::GDALSetRasterCategoryNames($$self, $csl);
-    Geo::GDAL::FFI::CSLDestroy($csl);
-}
-
 sub GetNoDataValue {
     my $self = shift;
     my $b = 0;
@@ -104,6 +81,7 @@ sub Read {
     $xoff //= 0;
     $yoff //= 0;
     my $t = Geo::GDAL::FFI::GDALGetRasterDataType($$self);
+    my $buf;
     my ($pc, $bytes_per_cell) = pack_char($t);
     my $w;
     $xsize //= Geo::GDAL::FFI::GDALGetRasterBandXSize($$self);
@@ -111,7 +89,7 @@ sub Read {
     $bufxsize //= $xsize;
     $bufysize //= $ysize;
     $w = $bufxsize * $bytes_per_cell;
-    my $buf = ' ' x ($bufysize * $w);
+    $buf = ' ' x ($bufysize * $w);
     my ($pointer, $size) = scalar_to_buffer $buf;
     Geo::GDAL::FFI::GDALRasterIO($$self, $Geo::GDAL::FFI::Read, $xoff, $yoff, $xsize, $ysize, $pointer, $bufxsize, $bufysize, $t, 0, 0);
     my $offset = 0;
@@ -188,7 +166,7 @@ sub GetColorInterpretation {
 sub SetColorInterpretation {
     my ($self, $i) = @_;
     my $tmp = $Geo::GDAL::FFI::color_interpretations{$i};
-    confess "Unknown color interpretation: $i." unless defined $tmp;
+    confess "Unknown color interpretation: $i\n" unless defined $tmp;
     $i = $tmp;
     Geo::GDAL::FFI::GDALSetRasterColorInterpretation($$self, $i);
 }
@@ -218,7 +196,6 @@ sub SetColorTable {
 }
 
 sub GetPiddle {
-    require PDL::Lite;  #  minimal load
     my ($self, $xoff, $yoff, $xsize, $ysize, $xdim, $ydim, $alg) = @_;
     $xoff //= 0;
     $yoff //= 0;
@@ -227,12 +204,12 @@ sub GetPiddle {
     $ysize //= $h - $yoff;
     my $t = Geo::GDAL::FFI::GDALGetRasterDataType($$self);
     my $pdl_t = $Geo::GDAL::FFI::data_type2pdl_data_type{$Geo::GDAL::FFI::data_types_reverse{$t}};
-    confess "The Piddle data_type is unsuitable." unless defined $pdl_t;
+    confess "The Piddle data_type is unsuitable.\n" unless defined $pdl_t;
     $xdim //= $xsize;
     $ydim //= $ysize;
     $alg //= 'NearestNeighbour';
     my $tmp = $Geo::GDAL::FFI::resampling{$alg};
-    confess "Unknown resampling scheme: $alg." unless defined $tmp;
+    confess "Unknown resampling scheme: $alg\n" unless defined $tmp;
     $alg = $tmp;
     my $bufxsize = $xsize;
     my $bufysize = $ysize;
@@ -240,21 +217,13 @@ sub GetPiddle {
     my $buf = ' ' x ($bufysize * $bufxsize * $bytes_per_cell);
     my ($pointer, $size) = scalar_to_buffer $buf;
     Geo::GDAL::FFI::GDALRasterIO($$self, $Geo::GDAL::FFI::Read, $xoff, $yoff, $xsize, $ysize, $pointer, $bufxsize, $bufysize, $t, 0, 0);
-    my $pdl;
-    if ($PDL::VERSION >= 2.091) {
-        $pdl = PDL->new_around_datasv(0+\$buf);
-        $pdl->set_datatype($pdl_t);
-        $pdl->setdims([$xdim, $ydim]);
-    }
-    else {
-        $pdl = PDL->new;
-        $pdl->set_datatype($pdl_t);
-        $pdl->setdims([ $xdim, $ydim ]);
-        my $data = $pdl->get_dataref();
-        # FIXME: see http://pdl.perl.org/PDLdocs/API.html how to wrap $buf into a piddle
-        $$data = $buf;
-        $pdl->upd_data;
-    }
+    my $pdl = PDL->new;
+    $pdl->set_datatype($pdl_t);
+    $pdl->setdims([$xdim, $ydim]);
+    my $data = $pdl->get_dataref();
+    # FIXME: see http://pdl.perl.org/PDLdocs/API.html how to wrap $buf into a piddle
+    $$data = $buf;
+    $pdl->upd_data;
     # FIXME: we want approximate equality since no data value can be very large floating point value
     my $bad = GetNoDataValue($self);
     return $pdl->setbadif($pdl == $bad) if defined $bad;
@@ -267,7 +236,7 @@ sub SetPiddle {
     $yoff //= 0;
     my ($w, $h) = $self->GetSize;
     my $t = $Geo::GDAL::FFI::pdl_data_type2data_type{$pdl->get_datatype};
-    confess "The Piddle data_type '".$pdl->get_datatype."' is unsuitable." unless defined $t;
+    confess "The Piddle data_type '".$pdl->get_datatype."' is unsuitable.\n" unless defined $t;
     $t = $Geo::GDAL::FFI::data_types{$t};
     my ($xdim, $ydim) = $pdl->dims();
     $xsize //= $xdim;
@@ -381,7 +350,7 @@ colors [c1...c4].
 
 =head2 SetColorTable
 
- $band->SetColorTable($color_table);
+ $band->GetColorTable($color_table);
 
 =head1 LICENSE
 
