@@ -5,8 +5,6 @@ use warnings;
 use Carp;
 use base 'Geo::GDAL::FFI::Object';
 
-our $VERSION = '0.13_004';
-
 sub GetName {
     my $self = shift;
     return $self->GetDescription;
@@ -22,7 +20,7 @@ sub Create {
         $o = Geo::GDAL::FFI::CSLAddString($o, "$key=$args->{Options}{$key}");
     }
     my $ds;
-    if ($args->{Source}) {
+    if (exists $args->{Source}) {
         my $src = ${$args->{Source}};
         my $s = $args->{Strict} // 0;
         my $ffi = FFI::Platypus->new;
@@ -36,16 +34,12 @@ sub Create {
         my $b = $args->{Bands} // 1;
         my $dt = $args->{DataType} // 'Byte';
         my $tmp = $Geo::GDAL::FFI::data_types{$dt};
-        unless (defined $tmp) {
-            confess "Unknown constant: $dt.";
-            Geo::GDAL::FFI::CSLDestroy($o);
-        }
+        confess "Unknown constant: $dt\n" unless defined $tmp;
         $ds = Geo::GDAL::FFI::GDALCreate($$self, $name, $w, $h, $b, $tmp, $o);
     }
-    Geo::GDAL::FFI::CSLDestroy($o);
     my $msg = Geo::GDAL::FFI::error_msg();
     if (!$ds || $msg) {
-        $msg //= "Driver " . $self->Name . " failed to create dataset '$name'.";
+        $msg //= "Dataset '$name' creation failed. (Driver = ".$self->Name.")";
         confess $msg;
     }
     return bless \$ds, 'Geo::GDAL::FFI::Dataset';
@@ -108,10 +102,7 @@ Optional, the dataset to copy.
 
 =item C<Progress>
 
-Optional, used only in dataset copy, a reference to a subroutine. The
-subroutine is called with three arguments C<($fraction, $msg, $data)>,
-where C<$fraction> is a number, C<$msg> is a string, and C<$data> is a
-pointer that is given as the progress data argument.
+Optional, used only in dataset copy, a reference to a subroutine.
 
 =item C<ProgressData>
 
