@@ -2,13 +2,10 @@ package Geo::GDAL::FFI::Feature;
 use v5.10;
 use strict;
 use warnings;
-use Config;
 use Carp;
 use Encode qw(decode encode);
 use FFI::Platypus::Buffer;
 
-our $VERSION = '0.13_004';
-
 sub new {
     my ($class, $defn) = @_;
     my $f = Geo::GDAL::FFI::OGR_F_Create($$defn);
@@ -50,20 +47,11 @@ sub Equals {
     return Geo::GDAL::FFI::OGR_F_Equal($$self, $$f);
 }
 
-sub field_index {
-    my ($self, $field_name, $is_geom) = @_;
-    my $index = $is_geom ?
-        Geo::GDAL::FFI::OGR_F_GetGeomFieldIndex($$self, $field_name) :
-        Geo::GDAL::FFI::OGR_F_GetFieldIndex($$self, $field_name);
-    confess "Field '$field_name' does not exist." if $index < 0;
-    return $index;
-}
-
 sub SetField {
     my $self = shift;
     my $i = shift;
     $i //= 0;
-    $i = $self->field_index($i) unless Geo::GDAL::FFI::isint($i);
+    $i = Geo::GDAL::FFI::OGR_F_GetFieldIndex($$self, $i) unless Geo::GDAL::FFI::isint($i);
     unless (@_) {
         Geo::GDAL::FFI::OGR_F_UnsetField($$self, $i) ;
         return;
@@ -75,9 +63,6 @@ sub SetField {
     }
     my $d = Geo::GDAL::FFI::OGR_F_GetFieldDefnRef($$self, $i);
     my $t = $Geo::GDAL::FFI::field_types_reverse{Geo::GDAL::FFI::OGR_Fld_GetType($d)};
-    if ($t =~ /^Integer64/ && $Config{use64bitint} ne 'define') {
-        confess "Your Perl does not support 64 bit integers.";
-    }
     Geo::GDAL::FFI::OGR_F_SetFieldInteger($$self, $i, $value) if $t eq 'Integer';
     Geo::GDAL::FFI::OGR_F_SetFieldInteger64($$self, $i, $value) if $t eq 'Integer64';
     Geo::GDAL::FFI::OGR_F_SetFieldDouble($$self, $i, $value) if $t eq 'Real';
@@ -129,13 +114,10 @@ sub SetField {
 sub GetField {
     my ($self, $i, $encoding) = @_;
     $i //= 0;
-    $i = $self->field_index($i) unless Geo::GDAL::FFI::isint($i);
+    $i = Geo::GDAL::FFI::OGR_F_GetFieldIndex($$self, $i) unless Geo::GDAL::FFI::isint($i);
     return unless $self->IsFieldSetAndNotNull($i);
     my $d = Geo::GDAL::FFI::OGR_F_GetFieldDefnRef($$self, $i);
     my $t = $Geo::GDAL::FFI::field_types_reverse{Geo::GDAL::FFI::OGR_Fld_GetType($d)};
-    if ($t =~ /^Integer64/ && $Config{use64bitint} ne 'define') {
-        confess "Your Perl does not support 64 bit integers.";
-    }
     return Geo::GDAL::FFI::OGR_F_GetFieldAsInteger($$self, $i) if $t eq 'Integer';
     return Geo::GDAL::FFI::OGR_F_GetFieldAsInteger64($$self, $i) if $t eq 'Integer64';
     return Geo::GDAL::FFI::OGR_F_GetFieldAsDouble($$self, $i) if $t eq 'Real';
@@ -184,28 +166,28 @@ sub GetField {
 sub IsFieldSet {
     my ($self, $i) = @_;
     $i //= 0;
-    $i = $self->field_index($i) unless Geo::GDAL::FFI::isint($i);
+    $i = Geo::GDAL::FFI::OGR_F_GetFieldIndex($$self, $i) unless Geo::GDAL::FFI::isint($i);
     return Geo::GDAL::FFI::OGR_F_IsFieldSet($$self, $i);
 }
 
 sub IsFieldNull {
     my ($self, $i) = @_;
     $i //= 0;
-    $i = $self->field_index($i) unless Geo::GDAL::FFI::isint($i);
+    $i = Geo::GDAL::FFI::OGR_F_GetFieldIndex($$self, $i) unless Geo::GDAL::FFI::isint($i);
     return Geo::GDAL::FFI::OGR_F_IsFieldNull($$self, $i);
 }
 
 sub IsFieldSetAndNotNull {
     my ($self, $i) = @_;
     $i //= 0;
-    $i = $self->field_index($i) unless Geo::GDAL::FFI::isint($i);
+    $i = Geo::GDAL::FFI::OGR_F_GetFieldIndex($$self, $i) unless Geo::GDAL::FFI::isint($i);
     return Geo::GDAL::FFI::OGR_F_IsFieldSetAndNotNull($$self, $i);
 }
 
 sub GetGeomField {
     my ($self, $i) = @_;
     $i //= 0;
-    $i = $self->field_index($i, 1) unless Geo::GDAL::FFI::isint($i);
+    $i = Geo::GDAL::FFI::OGR_F_GetGeomFieldIndex($$self, $i) unless Geo::GDAL::FFI::isint($i);
     my $g = Geo::GDAL::FFI::OGR_F_GetGeomFieldRef($$self, $i);
     confess "No such field: $i" unless $g;
     ++$Geo::GDAL::FFI::immutable{$g};
@@ -218,7 +200,7 @@ sub SetGeomField {
     my $g = pop;
     my $i = shift;
     $i //= 0;
-    $i = $self->field_index($i, 1) unless Geo::GDAL::FFI::isint($i);
+    $i = Geo::GDAL::FFI::OGR_F_GetGeomFieldIndex($$self, $i) unless Geo::GDAL::FFI::isint($i);
     if (ref $g eq 'ARRAY') {
         $g = Geo::GDAL::FFI::Geometry->new(@$g);
     }
