@@ -4,19 +4,17 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.13_004';
-
 sub new {
     my ($class, $args) = @_;
     $args //= {};
     my $name = $args->{Name} // '';
     my $self = bless \Geo::GDAL::FFI::OGR_FD_Create($name), $class;
-    if ($args->{Fields}) {
+    if (exists $args->{Fields}) {
         for my $field (@{$args->{Fields}}) {
             $self->AddField(Geo::GDAL::FFI::FieldDefn->new($field));
         }
     }
-    if ($args->{GeometryFields}) {
+    if (exists $args->{GeometryFields}) {
         my $first = 1;
         for my $field (@{$args->{GeometryFields}}) {
             if ($first) {
@@ -66,7 +64,7 @@ sub GetFieldDefn {
     my $i = $fname // 0;
     $i = Geo::GDAL::FFI::OGR_FD_GetFieldIndex($$self, $i) unless Geo::GDAL::FFI::isint($i);
     my $d = Geo::GDAL::FFI::OGR_FD_GetFieldDefn($$self, $i);
-    confess "No such field: $fname." unless $d;
+    confess "No such field: $fname" unless $d;
     ++$Geo::GDAL::FFI::immutable{$d};
     return bless \$d, 'Geo::GDAL::FFI::FieldDefn';
 }
@@ -85,7 +83,7 @@ sub GetGeomFieldDefn {
     my $i = $fname // 0;
     $i = Geo::GDAL::FFI::OGR_FD_GetGeomFieldIndex($$self, $i) unless Geo::GDAL::FFI::isint($i);
     my $d = Geo::GDAL::FFI::OGR_FD_GetGeomFieldDefn($$self, $i);
-    confess "No such field: $fname." unless $d;
+    confess "No such field: $fname" unless $d;
     ++$Geo::GDAL::FFI::immutable{$d};
     return bless \$d, 'Geo::GDAL::FFI::GeomFieldDefn';
 }
@@ -132,7 +130,7 @@ sub SetGeomType {
     my ($self, $type) = @_;
     $type //= 'Unknown';
     my $tmp = $Geo::GDAL::FFI::geometry_types{$type};
-    confess "Unknown geometry type: $type." unless defined $tmp;
+    confess "Unknown geometry type: $type\n" unless defined $tmp;
     Geo::GDAL::FFI::OGR_FD_SetGeomType($$self, $tmp);
 }
 
