@@ -4,8 +4,6 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.13_004';
-
 my %ref;
 
 sub new {
@@ -15,7 +13,7 @@ sub new {
     if (@_ == 1) {
         my $type = shift // '';
         my $tmp = $Geo::GDAL::FFI::geometry_types{$type};
-        confess "Empty or unknown geometry type: '$type'." unless defined $tmp;
+        confess "Empty or unknown geometry type: '$type'\n" unless defined $tmp;
         my $m = $type =~ /M$/;
         my $z = $type =~ /ZM$/ || $type =~ /25D$/;
         $g = Geo::GDAL::FFI::OGR_G_CreateGeometry($tmp);
@@ -26,7 +24,7 @@ sub new {
     } else {
         my ($format, $string, $sr) = @_;
         my $tmp = $Geo::GDAL::FFI::geometry_formats{$format};
-        confess "Empty or unknown geometry format: '$format'." unless defined $tmp;
+        confess "Empty or unknown geometry format: '$format'\n" unless defined $tmp;
         $sr = $$sr if $sr;
         if ($format eq 'WKT') {
             my $e = Geo::GDAL::FFI::OGR_G_CreateFromWkt(\$string, $sr, \$g);
@@ -38,7 +36,7 @@ sub new {
 
 sub DESTROY {
     my ($self) = @_;
-    Geo::GDAL::FFI::_deregister_parent_ref ($$self);
+    delete $Geo::GDAL::FFI::parent{$$self};
     if ($ref{$$self}) {
         delete $ref{$$self};
         return;
@@ -173,7 +171,7 @@ sub GetGeometryCount {
 sub GetGeometry {
     my ($self, $i) = @_;
     my $g = Geo::GDAL::FFI::OGR_G_GetGeometryRef($$self, $i);
-    Geo::GDAL::FFI::_register_parent_ref ($g, $self);
+    $Geo::GDAL::FFI::parent{$g} = $self;
     $ref{$g} = 1;
     return bless \$g, 'Geo::GDAL::FFI::Geometry';
 }
@@ -181,7 +179,7 @@ sub GetGeometry {
 sub AddGeometry {
     my ($self, $g) = @_;
     confess "Can't modify an immutable object." if $Geo::GDAL::FFI::immutable{$$self};
-    my $e = Geo::GDAL::FFI::OGR_G_AddGeometry($$self, $$g);
+    my $e = Geo::GDAL::FFI::OGR_G_OGR_G_AddGeometry($$self, $$g);
     return unless $e;
     confess(Geo::GDAL::FFI::error_msg());
 }
@@ -195,68 +193,13 @@ sub RemoveGeometry {
 }
 
 sub ExportToWKT {
-    my ($self, $variant) = @_;
-    $variant //= 'ISO';
+    my ($self) = @_;
     my $wkt = '';
-    if ($variant =~ /(?i)iso/) {
-        Geo::GDAL::FFI::OGR_G_ExportToIsoWkt($$self, \$wkt);
-    } else {
-        Geo::GDAL::FFI::OGR_G_ExportToWkt($$self, \$wkt);
-    }
+    Geo::GDAL::FFI::OGR_G_ExportToIsoWkt($$self, \$wkt);
     return $wkt;
 }
 *AsText = *ExportToWKT;
 
-sub ExportToGML {
-    my ($self, %options) = @_;
-    my $o = 0;
-    for my $key (keys %options) {
-        $o = Geo::GDAL::FFI::CSLAddString($o, "$key=$options{$key}");
-    }
-    my $p;
-    if ($o) {
-        $p = Geo::GDAL::FFI::OGR_G_ExportToGMLEx($$self, $o);
-        Geo::GDAL::FFI::CSLDestroy($o);
-    } else {
-        $p = Geo::GDAL::FFI::OGR_G_ExportToGML($$self);
-    }
-    my $ffi = FFI::Platypus->new;
-    my $gml = $ffi->cast(opaque => 'string', $p);
-    Geo::GDAL::FFI::VSIFree($p);
-    confess Geo::GDAL::FFI::error_msg() unless $gml;
-    return $gml;
-}
-
-sub ExportToKML {
-    my ($self) = @_;
-    my $p = Geo::GDAL::FFI::OGR_G_ExportToKML($$self);
-    my $ffi = FFI::Platypus->new;
-    my $kml = $ffi->cast(opaque => 'string', $p);
-    Geo::GDAL::FFI::VSIFree($p);
-    confess Geo::GDAL::FFI::error_msg() unless $kml;
-    return $kml;
-}
-
-sub ExportToJSON {
-    my ($self, %options) = @_;
-    my $o = 0;
-    for my $key (keys %options) {
-        $o = Geo::GDAL::FFI::CSLAddString($o, "$key=$options{$key}");
-    }
-    my $p;
-    if ($o) {
-        $p = Geo::GDAL::FFI::OGR_G_ExportToJsonEx($$self, $o);
-        Geo::GDAL::FFI::CSLDestroy($o);
-    } else {
-        $p = Geo::GDAL::FFI::OGR_G_ExportToJson($$self);
-    }
-    my $ffi = FFI::Platypus->new;
-    my $json = $ffi->cast(opaque => 'string', $p);
-    Geo::GDAL::FFI::VSIFree($p);
-    confess Geo::GDAL::FFI::error_msg() unless $json;
-    return $json;
-}
-
 sub Intersects {
     my ($self, $geom) = @_;
     return Geo::GDAL::FFI::OGR_G_Intersects($$self, $$geom);
@@ -314,45 +257,31 @@ sub Buffer {
 
 sub Intersection {
     my ($self, $geom) = @_;
-    confess "Undefined geometry." unless $geom;
-    $self = Geo::GDAL::FFI::OGR_G_Intersection($$self, $$geom);
-    confess Geo::GDAL::FFI::error_msg() unless $self;
-    return bless \$self, 'Geo::GDAL::FFI::Geometry';
+    return bless \Geo::GDAL::FFI::OGR_G_Intersection($$self, $$geom), 'Geo::GDAL::FFI::Geometry';
 }
 
 sub Union {
     my ($self, $geom) = @_;
-    confess "Undefined geometry." unless $geom;
-    $self = Geo::GDAL::FFI::OGR_G_Union($$self, $$geom);
-    confess Geo::GDAL::FFI::error_msg() unless $self;
-    return bless \$self, 'Geo::GDAL::FFI::Geometry';
+    return bless \Geo::GDAL::FFI::OGR_G_Union($$self, $$geom), 'Geo::GDAL::FFI::Geometry';
 }
 
 sub Difference {
     my ($self, $geom) = @_;
-    confess "Undefined geometry." unless $geom;
-    $self = Geo::GDAL::FFI::OGR_G_Difference($$self, $$geom);
-    confess Geo::GDAL::FFI::error_msg() unless $self;
-    return bless \$self, 'Geo::GDAL::FFI::Geometry';
+    return bless \Geo::GDAL::FFI::OGR_G_Difference($$self, $$geom), 'Geo::GDAL::FFI::Geometry';
 }
 
 sub SymDifference {
     my ($self, $geom) = @_;
-    confess "Undefined geometry." unless $geom;
-    $self = Geo::GDAL::FFI::OGR_G_SymDifference($$self, $$geom);
-    confess Geo::GDAL::FFI::error_msg() unless $self;
-    return bless \$self, 'Geo::GDAL::FFI::Geometry';
+    return bless \Geo::GDAL::FFI::OGR_G_SymDifference($$self, $$geom), 'Geo::GDAL::FFI::Geometry';
 }
 
 sub Distance {
     my ($self, $geom) = @_;
-    confess "Undefined geometry." unless $geom;
     return Geo::GDAL::FFI::OGR_G_Distance($$self, $$geom);
 }
 
 sub Distance3D {
     my ($self, $geom) = @_;
-    confess "Undefined geometry." unless $geom;
     return Geo::GDAL::FFI::OGR_G_Distance3D($$self, $$geom);
 }
 
@@ -400,45 +329,6 @@ sub IsRing {
     return Geo::GDAL::FFI::OGR_G_IsRing($$self);
 }
 
-sub GetEnvelope {
-    my ($self) = @_;
-    my $envelope = [0,0,0,0];
-    Geo::GDAL::FFI::OGR_G_GetEnvelope ($$self, $envelope);
-    return $envelope;
-}
-
-sub GetEnvelope3D {
-    my ($self) = @_;
-    my $envelope = [0,0,0,0,0,0];
-    Geo::GDAL::FFI::OGR_G_GetEnvelope3D ($$self, $envelope);
-    return $envelope;
-}
-
-sub MakeValid {
-    my ($self, %options) = @_;
-    my $o = 0;
-    for my $key (keys %options) {
-        $o = Geo::GDAL::FFI::CSLAddString($o, "$key=$options{$key}");
-    }
-    my $p;
-    if ($o) {
-        $p = Geo::GDAL::FFI::OGR_G_MakeValidEx($$self, $o);
-        Geo::GDAL::FFI::CSLDestroy($o);
-    } else {
-        $p = Geo::GDAL::FFI::OGR_G_MakeValid($$self);
-    }
-    confess Geo::GDAL::FFI::error_msg() unless $p;
-    return bless \$p, 'Geo::GDAL::FFI::Geometry';
-}
-
-sub Normalize {
-    my ($self) = @_;
-    my $g = Geo::GDAL::FFI::OGR_G_Normalize($$self);
-    confess Geo::GDAL::FFI::error_msg() unless $g;
-    return bless \$g, 'Geo::GDAL::FFI::Geometry';
-}
-
-
 1;
 
 =pod
@@ -566,30 +456,8 @@ reference and thus changing that geometry will change the parent.
 
  $geom->RemoveGeometry($i);
 
-=head2 ExportToWKT($variant)
-
- my $wkt = $geom->ExportToWKT($variant);
-
-Returns the geometry as WKT. $variant is optional (default is 'ISO').
-
 =head2 AsText
 
-Alias to ExportToWKT.
-
-=head2 ExportToGML(%options)
-
- my $gml = $geom->ExportToGML(%options);
-
-Returns the geometry as GML string. %options may contain options as
-described in GDAL documentation.
-
-=head2 ExportToJSON(%options)
-
- my $json = $geom->ExportToJSON(%options);
-
-Returns the geometry as JSON string. %options may contain options as
-described in GDAL documentation.
-
 =head2 Intersects
 
 =head2 Equals
@@ -640,33 +508,6 @@ described in GDAL documentation.
 
 =head2 IsRing
 
-=head2 GetEnvelope
-
-Returns a four element array reference containing
-[Xmin, Xmax, Ymin, Ymax].
-
-=head2 GetEnvelope3D
-
-Returns a six element array reference containing
-[Xmin, Xmax, Ymin, Ymax, Zmin, Zmax].
-
-=head2 MakeValid(%options)
-
- my $valid_geom = $geom->MakeValid(%options);
-
-Attempts to make an invalid geometry valid and returns that. %options
-may contain options as described in GDAL documentation.
-
-Requires GDAL version >= 3.0
-
-=head2 Normalize()
-
- my $normalized_geom = $geom->Normalize();
-
-Attempts to bring geometry into normalized/canonical form.
-
-Requires GDAL version >= 3.3
-
 =head1 LICENSE
 
 This software is released under the Artistic License. See
