@@ -4,8 +4,6 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.13_004';
-
 sub GetDescription {
     my $self = shift;
     return Geo::GDAL::FFI::GDALGetDescription($$self);
@@ -14,7 +12,7 @@ sub GetDescription {
 sub HasCapability {
     my ($self, $cap) = @_;
     my $tmp = $Geo::GDAL::FFI::capabilities{$cap};
-    confess "Unknown capability: $cap." unless defined $tmp;
+    confess "Unknown constant: $cap\n" unless defined $tmp;
     my $md = $self->GetMetadata('');
     return $md->{'DCAP_'.$cap};
 }
@@ -59,7 +57,6 @@ sub SetMetadata {
             $csl = Geo::GDAL::FFI::CSLAddString($csl, "$name=$metadata->{$name}");
         }
         my $err = Geo::GDAL::FFI::GDALSetMetadata($$self, $csl, $domain);
-        Geo::GDAL::FFI::CSLDestroy($csl);
         confess Geo::GDAL::FFI::error_msg() if $err == $Geo::GDAL::FFI::Failure;
         warn Geo::GDAL::FFI::error_msg() if $err == $Geo::GDAL::FFI::Warning;
     }
