@@ -4,8 +4,6 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.13_004';
-
 sub new {
     my ($class, $arg, @arg) = @_;
     my $sr;
@@ -15,8 +13,8 @@ sub new {
         $sr = Geo::GDAL::FFI::OSRNewSpatialReference($arg);
     } else {
         $sr = Geo::GDAL::FFI::OSRNewSpatialReference();
-        my $gdal = Geo::GDAL::FFI->get_instance;
-        $arg = $gdal->get_importer($arg);
+        my $fake = Geo::GDAL::FFI->fake;
+        $arg = $fake->get_importer($arg);
         if ($arg->($sr, @arg) != 0) {
             Geo::GDAL::FFI::OSRDestroySpatialReference($sr);
             $sr = 0;
@@ -28,20 +26,14 @@ sub new {
 
 sub DESTROY {
     my $self = shift;
-    #  OSRGetReferenceCount method not yet implemented
-    my $refcount = (Geo::GDAL::FFI::OSRReference ($$self)-1);
-    Geo::GDAL::FFI::OSRDereference ($$self);  #  immediately decrement 
-    if ($refcount == 0) {
-        #warn "Calling DESTROY method for $$self\n";
-        Geo::GDAL::FFI::OSRDestroySpatialReference($$self);
-    }
+    Geo::GDAL::FFI::OSRDestroySpatialReference($$self);
 }
 
 sub Export {
     my $self = shift;
     my $format = shift;
-    my $gdal = Geo::GDAL::FFI->get_instance;
-    my $exporter = $gdal->get_exporter($format);
+    my $fake = Geo::GDAL::FFI->fake;
+    my $exporter = $fake->get_exporter($format);
     my $x;
     if ($exporter->($$self, \$x, @_) != 0) {
         confess Geo::GDAL::FFI::error_msg();
@@ -52,8 +44,8 @@ sub Export {
 sub Set {
     my $self = shift;
     my $set = shift;
-    my $gdal = Geo::GDAL::FFI->get_instance;
-    my $setter = $gdal->get_setter($set);
+    my $fake = Geo::GDAL::FFI->fake;
+    my $setter = $fake->get_setter($set);
     if ($setter->($$self, @_) != 0) {
         confess Geo::GDAL::FFI::error_msg();
     }
